@@ -309,6 +309,8 @@ class MP3(AudioType):
                (22050, 24000, 16000), # MPEG 2  
                (44100, 48000, 32000)) # MPEG 1  
 
+    id3v2_frames = ['TPE1', 'TALB', 'TYER', 'TDRC']
+
     def __init__(self, file_):
 
         AudioType.__init__(self, file_)
@@ -360,7 +362,8 @@ class MP3(AudioType):
             self.id3v1 = None
 
         try:
-            self.id3v2 = dnuos.id3.ID3v2(self._f)
+            self.id3v2 = dnuos.id3.ID3v2(self._f,
+                                         limit_frames=self.id3v2_frames)
         except dnuos.id3.Error:
             self.id3v2 = None
 
@@ -493,7 +496,7 @@ class MP3(AudioType):
             vbrmethod = self.mp3header[7] & 15
             lowpass = self.mp3header[8]
             ath = self.mp3header[9] & 15
-            preset = self.mp3header[11] & 2047
+            preset = self.mp3header[11] & 0x1ff
 
             if preset > 0:
                 if preset == 320:
@@ -564,6 +567,8 @@ class MPC(AudioType):
 
     filetype = "MPC"
 
+    id3v2_frames = ['TPE1', 'TALB', 'TYER', 'TDRC']
+
     def __init__(self, file_):
 
         AudioType.__init__(self, file_)
@@ -602,13 +607,14 @@ class MPC(AudioType):
             self.id3v1 = None
 
         try:
-            self.id3v2 = dnuos.id3.ID3v2(self._f)
+            self.id3v2 = dnuos.id3.ID3v2(self._f,
+                                         limit_frames=self.id3v2_frames)
         except dnuos.id3.Error:
             self.id3v2 = None
 
     def artist(self):
 
-        res = {}
+        res = {'id3v1': None, 'id3v2': None}
         if self.id3v1 and self.id3v1.artist:
             res['id3v1'] = self.id3v1.artist
         if self.id3v2:
@@ -619,7 +625,7 @@ class MPC(AudioType):
 
     def album(self):
 
-        res = {}
+        res = {'id3v1': None, 'id3v2': None}
         if self.id3v1 and self.id3v1.album:
             res['id3v1'] = self.id3v1.album
         if self.id3v2:
@@ -628,6 +634,17 @@ class MPC(AudioType):
                     res['id3v2'] = frame.value
         return res
 
+    def year(self):
+
+        res = {'id3v1': None, 'id3v2': None}
+        if self.id3v1 and self.id3v1.year:
+            res['id3v1'] = self.id3v1.year
+        if self.id3v2:
+            for frame in self.id3v2.frames:
+                if frame.id in ('TYER', 'TDRC') and hasattr(frame, 'value'):
+                    res['id3v2'] = frame.value
+        return res
+
     _search_header = re.compile('MP+').search
 
     def headerstart(self):
